@@ -15,7 +15,7 @@ __author__ = 'liaozhaoyan'
 import shlex
 import re
 from collections import deque
-from surftrace import CexecCmd
+from .execCmd import CexecCmd
 from datetime import datetime
 
 HIST2_MAX = 65
@@ -165,7 +165,7 @@ def _transSysEntry(line, res):
 
 def _transEvents(line, res):
     name, rest = line.split(':', 1)  # do not parse events format.
-    res['name'] = name
+    res['name'] = name.strip()
     res['args'] = rest.strip()
 
 
